==> camas_1.0.30.orig.tar.gz: camas-1.0.30/server/etc/include/camas/language.h <==
// Messages
//
//login
#define M_LOGIN 1
#define M_PASSWORD 2
#define M_NOLOGIN 3
#define M_LOGINERROR 4
#define M_IMAPERROR 10
#define M_SMTPERROR 11
#define M_SAVEDUSERINTERFACE 12
#define M_USERINTERFACE 13
#define M_LOGIN_OK 14
#define M_SMTPOK 15
// page header
#define M_NEWMAIL 50
#define M_MAILBOX 51
#define M_MAILBOXES 52
#define M_FILES 53
#define M_PREFS 54
#define M_LOGOUT 55
#define M_CURRMAILBOX 56
#define M_CHECKACTIVEMAILBOXES 57
// compose
#define M_SEND 100
#define M_CANCELSEND 101
#define M_SENDMOREFILES 102
#define M_COMPOSEMAIL 103
#define M_SPELLCHECK 104
#define M_DONTSAVEMAIL 105
#define M_ADDFILEASATTACHMENT 106
#define M_NOATTACHMENTS 107
#define M_ADDATTACHMENT 108
#define M_REMOVEMARKEDATTACHMENTS 109
#define M_UPLOADATTACHMENT 110
#define M_ADDMARKEDTOATTACHMENTS 111
#define M_UPLOADTOATTACHMENTS 112
#define M_BACKTOCOMPOSE 113
#define M_NOATTACHFILES 114
#define M_ATTACHMENTSHEADER 115
#define M_SENDSAVEFAILED 116
#define M_SENDNORECV 117
#define M_DSN_DELAY 118
#define M_DSN_SUCCESS 119
#define M_SAVEMAILCOPY 120
#define M_SAVEDRAFT 121
#define M_MDN 122
#define M_SENDBROKENADDR 123
#define M_SAVEMAILCOPY 124
// mailindex
#define M_DELETEMARKED 200
#define M_MOVEMARKED 201
#define M_SELECTMBOX 202
#define M_CHECKNEWMAIL 203
#define M_MAILSHOWN 204
#define M_BACKN 205
#define M_FORWARDN 206
#define M_NUMBER 207
#define M_DELETEMARKEDP 208
#define M_DELETEMARKEDNONE 209
#define M_CHANGESORTORDER 210
#define M_MOVETOTRASH 211
#define M_DELETEALLTRASH 212
#define M_NOMAILS 213
#define M_MARKALL 214
// mailboxlist
#define M_MBOXNAME 300
#define M_DELETEMARKEDMBOX 301
#define M_CREATEMBOX 302
#define M_NEWMBOXNAME 303
#define M_MBOXREMOVEP 350
#define M_MBOXMARKONE 351
#define M_NEWMBOXNONAME 352
#define M_CREATEMBOXERROR 353
#define M_INBOX 354
#define M_PREVIOUS_LEVEL 355
#define M_FOLDER_PATH 356
#define M_BOXTRASH 357
#define M_BOXSENTMAIL 358
#define M_RENAMEMBOX 359
#define M_RENAMEMBOXERROR 360
#define M_NOMBOXERROR 361
#define M_BOXDRAFTS 362
// files
#define M_FILENAME 400
#define M_SIZE 401
#define M_MIMETYPE 402
#define M_DELETEMARKEDFILES 403
#define M_UPLOAD 404
#define M_AVAILSPACE 405
#define M_WINDOWSBUG 406
#define M_NOFILES 407
// preferences
#define M_PNAME 500
#define M_PMAILADDRESS 501
#define M_PMAILPATH 502
#define M_PINCLUDEMAIL 503
#define M_PQUOTEPREFIX 504
#define M_PSIGNATURE 505
#define M_PINACTIVELOGOUT 506
#define M_PSAVEANDUSE 550
#define M_PVISIBLEMESSAGES 507
#define M_PSORTORDER 508
#define M_PSORTORDERS 509
#define M_PTRASHFOLDER 510
#define M_PSENTFOLDER 511
#define M_PDEFAULTBCC 512
#define M_PSAVEATTACHMENTS 513
#define M_PLANGUAGE 514
#define M_PUSERINTERFACE 515
#define M_PHEADER 518
#define M_PHEADERDESC 519
#define M_PSORTCOLUMN 520
#define M_PSHOWHTML 521
#define M_PSHOWHIDDENHEADERS 522
#define M_PADDRESSBOOK 523
#define M_PSHOWTEXT 525
#define M_PDRAFTSFOLDER 526
// logout
#define M_LOGOUTMSG 600
#define M_LOGGEDOUT 601
// dialog
#define M_QUESTION 700
#define M_INFO 701
// readmail
#define M_REPLY 800
#define M_READPREV 801
#define M_READNEXT 802
#define M_ATTACHMENTLINK 803
#define M_MAILMISSING 804
#define M_MAILMISSINGBACK 805
#define M_DELETE 806
#define M_FORWARD 807
#define M_MAIL 808
#define M_SHOWFULLHEADERS 809
#define M_HIDEFULLHEADERS 810
#define M_MAILTOOBIG 811
#define M_REPLYTOALL 812
#define M_MOVETHISTOTRASH 813
#define M_CHARSETWARNING 814
#define M_CONTINUECOMPOSE 815
#define M_NOTIFYTO 816
//spellcheck
#define M_SPELLDONE 900
#define M_SPELLPREV 901
#define M_SPELLNEXT 902
#define M_SPELLCHANGETO 903
#define M_SPELLSUGGESTIONS 904
// mailheaders
#define M_FROM 1000
#define M_TO 1001
#define M_CC 1002
#define M_BCC 1003
#define M_SUBJECT 1004
#define M_ATTACHMENTS 1005
#define M_TIME 1006
#define M_DATE 1007
#define M_DELAY 1008
// table heads
#define M_MARKFLAG 1100
#define M_NEWFLAG 1101
#define M_ANSWEREDFLAG 1102
// address book
#define M_ADDRESSBOOKTITLE 1200
#define M_ADDRESSBOOK 1201
#define M_INDEXNAMERECIPIENT 1202
#define M_INDEXNAMEEDIT 1203
#define M_ADDRESS 1204
#define M_NOADDRESSES 1205
#define M_NEWADDRESS 1206
#define M_EDITADDRESS 1207
#define M_ADDADDRESS 1208
#define M_INDEXNAME 1209
#define M_ADDRESSFORMAT 1210
#define M_SAVEADDRESS 1211
#define M_DELETEADDRESS 1212
#define M_CANCELADDRESS 1213
#define M_CANNOTIMPORT 1214
#define M_IMPORTADDRESSBOOKTITLE 1215
#define M_UPLOADADDRESSBOOK 1216
#define M_PINELOCATION 1217
#define M_UPLOADANDIMPORT 1218
#define M_IMPORTADDRESSBOOK 1219
#define M_GLOBALADDRESSES 1220
//ldap support
#define M_LDAPTITLE 1300
#define M_LDAP 1301
#define M_SEARCHLDAP 1302
#define M_NAMECONT 1303
#define M_OU 1304
// mail notification
#define M_MAILNOTIFYWINDOW 1400
#define M_GETNEWMAIL 1401
// search mail
#define M_SEARCHMAILTITLE 1500
#define M_SEARCHMAIL 1501
#define M_SEARCHMAILBOX 1502
#define M_SEARCHANYWHERE 1503
#define M_SEARCHFROMFIELD 1504
#define M_SEARCHTOFIELD 1505
#define M_SEARCHSUBJECT 1506
#define M_SEARCHBODY 1507
#define M_SEARCHAND 1508
#define M_SEARCHSHOWINGMAIL 1509
// mail filter book
#define M_FILTERBOOKTITLE 1600
#define M_FILTERBOOK 1601
#define M_INDEXNAMERECIPIENTFILTER 1602
#define M_INDEXNAMEEDITFILTER 1603
#define M_ADDRESSFILTER 1604
#define M_NOADDRESSESFILTER 1605
#define M_NEWADDRESSFILTER 1606
#define M_EDITADDRESSFILTER 1607
#define M_INDEXNAMEFIELDFILTER 1608
#define M_INDEXNAMEEDITFIELDFILTER 1609
#define M_ADDADDRESSFILTER 1610
#define M_SAVEADDRESSFILTER 1611
#define M_DELETEADDRESSFILTER 1612
#define M_CANCELADDRESSFILTER 1613
#define M_INDEXFIELDFILTER 1614
#define M_FILTERFOLDER 1615
#define M_INDEXNAMEFILTER 1616
#define M_EDITFILTER 1617
#define M_SELECTFIELD 1618
#define M_EMPTYADDRESSFILTER 1619
#define M_PADDRESSBOOKFILTER 1620

#define M_ADDRECIPIENTS 1700
#define M_PORGANIZATION 1701

// general
#define M_YES 2000
#define M_NO 2001
#define M_DIALOGOK 2002
#define M_DIALOGCANCEL 2003

// misc
#define M_MDNMESSAGE 4000
#define M_MDNHEADER 4001
#define M_ENDSESSION 4002

// dates
#define M_TODAY 5000
#define M_MONDAY 5001
#define M_TUESDAY 5002
#define M_WEDNESDAY 5003
#define M_THURSDAY 5004
#define M_FRIDAY 5005
#define M_SATURDAY 5006
#define M_SUNDAY 5007

==> camas_1.2.21.orig.tar.gz: camas-1.2.21.orig/server/etc/include/camas/language.h <==
#ifndef __LANGUAGE_H
#define __LANGUAGE_H

// Messages
//
//login
#define M_LOGIN 1
#define M_PASSWORD 2
#define M_NOLOGIN 3
#define M_LOGINERROR 4
#define M_IMAPERROR 10
#define M_SMTPERROR 11
#define M_SAVEDUSERINTERFACE 12
#define M_USERINTERFACE 13
#define M_LOGIN_OK 14
#define M_SMTPOK 15
#define M_IMAPSERVER 17
#define M_PORT 19
#define M_ADDRBOOKERRROR 20
// page header
#define M_NEWMAIL 50
#define M_MAILBOX 51
#define M_MAILBOXES 52
#define M_FILES 53
#define M_PREFS 54
#define M_LOGOUT 55
#define M_CURRMAILBOX 56
#define M_CHECKACTIVEMAILBOXES 57
// compose
#define M_SEND 100
#define M_CANCELSEND 101
#define M_SENDMOREFILES 102
#define M_COMPOSEMAIL 103
#define M_SPELLCHECK 104
#define M_DONTSAVEMAIL 105
#define M_ADDFILEASATTACHMENT 106
#define M_NOATTACHMENTS 107
#define M_ADDATTACHMENT 108
#define M_REMOVEMARKEDATTACHMENTS 109
#define M_UPLOADATTACHMENT 110
#define M_ADDMARKEDTOATTACHMENTS 111
#define M_UPLOADTOATTACHMENTS 112
#define M_BACKTOCOMPOSE 113
#define M_NOATTACHFILES 114
#define M_ATTACHMENTSHEADER 115
#define M_SENDSAVEFAILED 116
#define M_SENDNORECV 117
#define M_DSN_DELAY 118
#define M_DSN_SUCCESS 119
#define M_SAVEMAILCOPY 120
#define M_SAVEDRAFT 121
#define M_MDN 122
#define M_SENDBROKENADDR 123
#define M_SAVEMAILCOPY 124
#define M_SEARCHREPLACE 126
#define M_CHECKBCC 127
#define M_SENDBLIND 128
#define M_ATTACHTOOBIG 129
// mailindex
#define M_DELETEMARKED 200
#define M_MOVEMARKED 201
#define M_SELECTMBOX 202
#define M_CHECKNEWMAIL 203
#define M_MAILSHOWN 204
#define M_BACKN 205
#define M_FORWARDN 206
#define M_NUMBER 207
#define M_DELETEMARKEDP 208
#define M_DELETEMARKEDNONE 209
#define M_CHANGESORTORDER 210
#define M_MOVETOTRASH 211
#define M_DELETEALLTRASH 212
#define M_NOMAILS 213
#define M_MARKALL 214
#define M_SHOWALLAFTERSEARCH 215
#define M_NOSEARCHRESULTS 216
#define M_HISTSEARCH 217
#define M_HISTFLAG 218
#define M_EBACKN 219
#define M_EFORWARDN 220
#define M_SENDMARKEDDRAFTS 221
#define M_SENDMARKEDDRAFTSMOVE 222
#define M_ARCHIVE 223
#define M_THREADSHOW 224
#define M_REPLYMARKED 225
#define M_REPLYMOVEMARKED 226
// mailboxlist
#define M_MBOXNAME 300
#define M_DELETEMARKEDMBOX 301
#define M_CREATEMBOX 302
#define M_NEWMBOXNAME 303
#define M_MBOXREMOVEP 350
#define M_MBOXMARKONE 351
#define M_NEWMBOXNONAME 352
#define M_CREATEMBOXERROR 353
#define M_INBOX 354
#define M_PREVIOUS_LEVEL 355
#define M_FOLDER_PATH 356
#define M_BOXTRASH 357
#define M_BOXSENTMAIL 358
#define M_RENAMEMBOX 359
#define M_RENAMEMBOXERROR 360
#define M_NOMBOXERROR 361
#define M_BOXDRAFTS 362
#define M_BOXANSWERED 363
#define M_TOTALSIZE 364
#define M_OF 365
#define M_USED 366
#define M_FOLDER 367
#define M_MESSAGES 368
#define M_UNSEEN 369
#define M_SHARED_BOXTRASH 370
#define M_SHARED_BOXSENTMAIL 371
#define M_SHARED_BOXDRAFTS 372
#define M_SHARED_BOXANSWERED 373
#define M_NEW 374
#define M_QUOTA 375
// files
#define M_FILENAME 400
#define M_SIZE 401
#define M_MIMETYPE 402
#define M_DELETEMARKEDFILES 403
#define M_UPLOAD 404
#define M_AVAILSPACE 405
#define M_WINDOWSBUG 406
#define M_NOFILES 407
// preferences
#define M_PNAME 500
#define M_PMAILADDRESS 501
#define M_PMAILPATH 502
#define M_PINCLUDEMAIL 503
#define M_PQUOTEPREFIX 504
#define M_PSIGNATURE 505
#define M_PINACTIVELOGOUT 506
#define M_PSAVEANDUSE 550
#define M_PVISIBLEMESSAGES 507
#define M_PSORTORDER 508
#define M_PSORTORDERS 509
#define M_PTRASHFOLDER 510
#define M_PSENTFOLDER 511
#define M_PDEFAULTBCC 512
#define M_PSAVEATTACHMENTS 513
#define M_PLANGUAGE 514
#define M_PUSERINTERFACE 515
#define M_PHEADER 518
#define M_PHEADERDESC 519
#define M_PSORTCOLUMN 520
#define M_PSHOWHTML 521
#define M_PSHOWHIDDENHEADERS 522
#define M_PADDRESSBOOK 523
#define M_PSHOWTEXT 525
#define M_PDRAFTSFOLDER 526
#define M_PAUTOFILTER 527
#define M_PANSWEREDFOLDER 528
#define M_PSENDBLIND 529
#define M_PPOSTLOGINSCREEN 530
#define	M_PREPLYONTOP	531
#define M_PENABLEDISABLECACHEFEEDER 532
// logout
#define M_LOGOUTMSG 600
#define M_LOGGEDOUT 601
#define M_LOGOUTCLOSE	602
#define	M_LOGOUTRELOAD	603
// dialog
#define M_QUESTION 700
#define M_INFO 701
// readmail
#define M_REPLY 800
#define M_READPREV 801
#define M_READNEXT 802
#define M_ATTACHMENTLINK 803
#define M_MAILMISSING 804
#define M_MAILMISSINGBACK 805
#define M_DELETE 806
#define M_FORWARD 807
#define M_MAIL 808
#define M_SHOWFULLHEADERS 809
#define M_HIDEFULLHEADERS 810
#define M_MAILTOOBIG 811
#define M_REPLYTOALL 812
#define M_MOVETHISTOTRASH 813
#define M_CHARSETWARNING 814
#define M_CONTINUECOMPOSE 815
#define M_NOTIFYTO 816
#define M_REPLYMOVE 819
#define M_REPLYTOALLMOVE 820
#define M_FORWARDMOVE 821
#define M_CONTINUECOMPOSEMOVE 822
#define M_BACKTOMAILINDEX 823
//spellcheck
#define M_SPELLDONE 900
#define M_SPELLPREV 901
#define M_SPELLNEXT 902
#define M_SPELLCHANGETO 903
#define M_SPELLSUGGESTIONS 904
#define M_NOSPELLINGERRORS 905
#define M_MANUALCORRECTION 906
// mailheaders
#define M_FROM 1000
#define M_TO 1001
#define M_CC 1002
#define M_BCC 1003
#define M_SUBJECT 1004
#define M_ATTACHMENTS 1005
#define M_TIME 1006
#define M_DATE 1007
#define M_DELAY 1008
#define M_RECEIVED 1009
// table heads
#define M_MARKFLAG 1100
#define M_NEWFLAG 1101
#define M_ANSWEREDFLAG 1102
// address book
#define M_ADDRESSBOOKTITLE 1200
#define M_ADDRESSBOOK 1201
#define M_INDEXNAMERECIPIENT 1202
#define M_INDEXNAMEEDIT 1203
#define M_ADDRESS 1204
#define M_NOADDRESSES 1205
#define M_NEWADDRESS 1206
#define M_EDITADDRESS 1207
#define M_ADDADDRESS 1208
#define M_INDEXNAME 1209
#define M_ADDRESSFORMAT 1210
#define M_SAVEADDRESS 1211
#define M_DELETEADDRESS 1212
#define M_CANCELADDRESS 1213
#define M_CANNOTIMPORT 1214
#define M_IMPORTADDRESSBOOKTITLE 1215
#define M_UPLOADADDRESSBOOK 1216
#define M_PINELOCATION 1217
#define M_UPLOADANDIMPORT 1218
#define M_IMPORTADDRESSBOOK 1219
#define M_GLOBALADDRESSES 1220
#define M_DELETEALLADDRESS 1221
#define M_SELECT 1222
#define M_EMAILADDRESS 1223
#define M_SURNAME 1224
#define M_NICKNAME 1225
#define M_HOMEPHONE 1226
#define M_WORKPHONE 1227
#define M_WORKSTATE 1228
#define M_TITLE 1229
#define M_COMPANY 1230
#define M_DEPARTMENT 1231
#define M_HOMEPOSTALADDRESS 1232
#define M_WORKPOSTALADDRESS 1233
#define M_WORKCITY 1234
#define M_WORKSTATE 1235
#define M_WORKCOUNTRY 1236
#define M_PAGER 1237
#define M_MOBILE 1238
#define M_URI 1239
#define M_DESCRIPTION 1240
#define M_POSTALCODE 1241
#define M_DESTINATIONIMPORT 1242
#define M_SELECTMATCHINGFIELDS 1243
#define M_IMPORTEDFIELDS 1244
#define M_AVAILABLEFIELDS 1245
#define M_MUSTSELECTFIELD 1246
#define M_ADDRESSBOOKWRITEPROBLEM 1247
//ldap support
#define M_LDAPTITLE 1300
#define M_LDAP 1301
#define M_SEARCHLDAP 1302
#define M_NAMECONT 1303
#define M_OU 1304
// mail notification
#define M_MAILNOTIFYWINDOW 1400
#define M_GETNEWMAIL 1401
// search mail
#define M_SEARCHMAILTITLE 1500
#define M_SEARCHMAIL 1501
#define M_STICKYFILTER 1502
#define M_SEARCHANYWHERE 1503
#define M_SEARCHFROMFIELD 1504
#define M_SEARCHTOFIELD 1505
#define M_SEARCHSUBJECT 1506
#define M_SEARCHBODY 1507
#define M_SEARCHAND 1508
#define M_SEARCHSHOWINGMAIL 1509
#define M_NOSEARCHREMEMBER 1510
#define M_SEARCHALLMBOX 1511
#define M_SEARCHRECURSIVE 1512
#define M_SEARCHCACHENOTFEEDED 1513
#define M_SEARCHHEADERS 1514
// mail filter book
#define M_FILTERBOOKTITLE 1600
#define M_FILTERBOOK 1601
#define M_INDEXNAMERECIPIENTFILTER 1602
#define M_INDEXNAMEEDITFILTER 1603
#define M_ADDRESSFILTER 1604
#define M_NOADDRESSESFILTER 1605
#define M_NEWADDRESSFILTER 1606
#define M_EDITADDRESSFILTER 1607
#define M_INDEXNAMEFIELDFILTER 1608
#define M_INDEXNAMEEDITFIELDFILTER 1609
#define M_ADDADDRESSFILTER 1610
#define M_SAVEADDRESSFILTER 1611
#define M_DELETEADDRESSFILTER 1612
#define M_CANCELADDRESSFILTER 1613
#define M_INDEXFIELDFILTER 1614
#define M_FILTERFOLDER 1615
#define M_INDEXNAMEFILTER 1616
#define M_EDITFILTER 1617
#define M_SELECTFIELD 1618
#define M_EMPTYADDRESSFILTER 1619
#define M_PADDRESSBOOKFILTER 1620
#define M_ADDRECIPIENTS 1700
#define M_PORGANIZATION 1701

// general
#define M_YES 2000
#define M_NO 2001
#define M_DIALOGOK 2002
#define M_DIALOGCANCEL 2003

// misc
#define M_MDNMESSAGE 4000
#define M_MDNHEADER 4001
#define M_ENDSESSION 4002

// dates
#define M_TODAY 5000
#define M_MONDAY 5001
#define M_TUESDAY 5002
#define M_WEDNESDAY 5003
#define M_THURSDAY 5004
#define M_FRIDAY 5005
#define M_SATURDAY 5006
#define M_SUNDAY 5007

// Compose Mail localizations
#define M_FWD_SEP     6000
#define M_FWD_CC      6001
#define M_FWD_DATE    6002
#define M_FWD_FROM    6003
#define M_FWD_REPLYTO 6004
#define M_FWD_SUBJECT 6005
#define M_FWD_TO      6006
#define M_FWD_REP_SEP 6007

#endif __LANGUAGE_H
/*                                                                             
 * Local Variables:                                                            
 * c-basic-offset: 2                                                           
 * End:                                                                        
 *                                                                             
 * vim: softtabstop=2 tabstop=2 expandtab autoindent formatoptions=croqlt smartindent cindent shiftwidth=2
 */
